==> scanbot_sdk-2.13.3-alpha01.tar.gz: ios/Classes/Classical Component/Configurations/BarcodeScannerConfiguration.swift <==
//
//  BarcodeScannerConfiguration.swift
//  scanbot_sdk
//
//  Created by Seifeddine Bouzid on 28.03.23.
//

import Foundation
import ScanbotSDK

struct BarcodeScannerConfiguration {
    
    var flashEnabled: Bool?
    var zoomConfiguration: SBSDKBaseScannerZoomConfiguration?
    var viewFinderConfiguration: SBSDKBaseScannerViewFinderConfiguration?
    var selectionOverlayConfiguration: ScannerSelectionOverlayConfiguration?
    var scannerConfiguration: ScannerConfiguration?
    
    init() { }
    
    init(_ arguments: [String: Any?]?) {
        if let arguments {
            self = BarcodeScannerConfiguration.parseArguments(arguments)
            print(self)
        }
    }
    
    private static func parseArguments(_ arguments: [String: Any?]) -> BarcodeScannerConfiguration {
        print(arguments)
        var configuration = BarcodeScannerConfiguration()
        
        if let flashEnabled = arguments["flashEnabled"] as? Bool {
            configuration.flashEnabled = flashEnabled
        }
        
        if let cameraZoomFactor = arguments["cameraZoomFactor"] as? CGFloat {
            let zoomConfig = SBSDKBaseScannerZoomConfiguration.default()
            zoomConfig.initialZoomFactor = cameraZoomFactor
            configuration.zoomConfiguration = zoomConfig
        }
        
        configuration.viewFinderConfiguration = arguments.finderConfiguration
        
        if let scannerConfiguration = arguments["scannerConfiguration"] as? [String: Any] {
            configuration.scannerConfiguration = ScannerConfiguration(scannerConfiguration)
        }
        
        if let overlayConfiguration = arguments["overlayConfiguration"] as? [String: Any] {
            configuration.selectionOverlayConfiguration = ScannerSelectionOverlayConfiguration(overlayConfiguration)
        }
        
        return configuration
    }
    
    struct ScannerSelectionOverlayConfiguration {
        var automaticSelectionEnabled: Bool = false
        var selectionOverlayEnabled: Bool = false
        var selectionPolygonColor: UIColor = UIColor.green
        var selectionOverlayTextFormat: SBSDKBarcodeOverlayFormat = .codeAndType
        var selectionTextColor: UIColor = .black
        var selectionTextContainerColor: UIColor = UIColor.green
        
        init() { }
        
        init(_ arguments: [String: Any]) {
            self = ScannerSelectionOverlayConfiguration.parseArguments(arguments: arguments)
        }
        
        private static func parseArguments(arguments: [String: Any]) -> ScannerSelectionOverlayConfiguration {
            var configuration = ScannerSelectionOverlayConfiguration()
            
            if let value = arguments["overlayEnabled"] as? Bool {
                configuration.selectionOverlayEnabled = value
            }
            
            if let value = arguments["automaticSelectionEnabled"] as? Bool {
                configuration.automaticSelectionEnabled = value
            }
            
            if arguments["textFormat"] is String {
                configuration.selectionOverlayTextFormat = SBSDKBarcodeOverlayFormat.fromArguments(arguments)!
            }
            if let hex = arguments["polygonColor"] as? String {
                configuration.selectionPolygonColor = UIColor(hexString: hex)
            }
            if let hex = arguments["textColor"] as? String {
                configuration.selectionTextColor = UIColor(hexString: hex)
            }
            if let hex = arguments["textContainerColor"] as? String {
                configuration.selectionTextContainerColor = UIColor(hexString: hex)
            }
           return configuration 
        }
    }
    struct ScannerConfiguration {
        
        var acceptedDocumentTypes: [SBSDKBarcodeDocumentType]?
        var acceptedBarcodeTypes: [SBSDKBarcodeType]?
        var engineMode: SBSDKBarcodeEngineMode?
        var additionalDetectionParameters: SBSDKBarcodeAdditionalParameters?
        var enableGS1Decoding: Bool?
        var minimumTextLength: UInt?
        var maximumTextLength: UInt?
        var minimum1DBarcodesQuietZone: UInt?
        var msiPlesseyChecksumAlgorithm: SBSDKBarcodeMSIPlesseyChecksumAlgorithm?
        var stripCheckDigits: Bool?
        var barcodeImageGenerationType: SBSDKBarcodeImageGenerationType?
        
        init() { }
        
        init(_ arguments: [String: Any]) {
            self = ScannerConfiguration.parseArguments(arguments: arguments)
        }
        
        private static func parseArguments(arguments: [String: Any]) -> ScannerConfiguration {
            var configuration = ScannerConfiguration()
            
            if arguments["acceptedDocumentFormats"] is [String] {
                configuration.acceptedDocumentTypes = SBSDKBarcodeDocumentType.fromArguments(arguments)
            }

            if arguments["barcodeFormats"] is [String] {
                configuration.acceptedBarcodeTypes = SBSDKBarcodeType.fromArguments(arguments)
            }
            
            if arguments["engineMode"] is String {
                configuration.engineMode = SBSDKBarcodeEngineMode.fromArguments(arguments)!
            }
            
            if let additionalParams = arguments["additionalParameters"] as? [String: Any] {
                configuration.additionalDetectionParameters = SBSDKBarcodeAdditionalParameters(from: additionalParams)
            }
            
            if let value = arguments["gs1DecodingEnabled"] as? Bool {
                configuration.additionalDetectionParameters?.enableGS1Decoding = value
            }
            
            if let value = arguments["minimumTextLength"] as? UInt {
                configuration.additionalDetectionParameters?.minimumTextLength = value
            }
            
            if let value = arguments["maximumTextLength"] as? UInt {
                configuration.additionalDetectionParameters?.maximumTextLength = value
            }
            
            if let value = arguments["minimum1DBarcodesQuietZone"] as? UInt {
                configuration.additionalDetectionParameters?.minimum1DBarcodesQuietZone = value
            }
            
            if let value = arguments["msiPlesseyChecksumAlgorithm"] as? String {
                configuration.additionalDetectionParameters?.msiPlesseyChecksumAlgorithm = SBSDKBarcodeMSIPlesseyChecksumAlgorithm(from: value)
            }
            
            if let value = arguments["stripCheckDigits"] as? Bool {
                configuration.additionalDetectionParameters?.stripCheckDigits = value
            }
            
            if let barcodeImageGenerationType = arguments["barcodeImageGenerationType"] as? String {
                configuration.barcodeImageGenerationType = SBSDKBarcodeImageGenerationType(from: barcodeImageGenerationType)
            }
            return configuration
        }
    }
}

==> scanbot_sdk-4.2.1-alpha01.tar.gz: ios/Classes/Classical Component/Configurations/BarcodeScannerConfiguration.swift <==
//
//  BarcodeScannerConfiguration.swift
//  scanbot_sdk
//
//  Created by Seifeddine Bouzid on 28.03.23.
//

import Foundation
import ScanbotSDK

struct BarcodeScannerConfiguration {
    
    var flashEnabled: Bool?
    var zoomConfiguration: SBSDKBaseScannerZoomConfiguration?
    var viewFinderConfiguration: SBSDKBaseScannerViewFinderConfiguration?
    var selectionOverlayConfiguration: ScannerTrackingOverlayConfiguration?
    var scannerConfiguration: ScannerConfiguration?
    
    init() { }
    
    init(_ arguments: [String: Any?]?) {
        if let arguments {
            self = BarcodeScannerConfiguration.parseArguments(arguments)
            print(self)
        }
    }
    
    private static func parseArguments(_ arguments: [String: Any?]) -> BarcodeScannerConfiguration {
        print(arguments)
        var configuration = BarcodeScannerConfiguration()
        
        if let flashEnabled = arguments["flashEnabled"] as? Bool {
            configuration.flashEnabled = flashEnabled
        }
        
        if let cameraZoomFactor = arguments["cameraZoomFactor"] as? CGFloat {
            let zoomConfig = SBSDKBaseScannerZoomConfiguration.default()
            zoomConfig.initialZoomFactor = cameraZoomFactor
            configuration.zoomConfiguration = zoomConfig
        }
        
        configuration.viewFinderConfiguration = arguments.finderConfiguration
        
        if let scannerConfiguration = arguments["scannerConfiguration"] as? [String: Any] {
            configuration.scannerConfiguration = ScannerConfiguration(scannerConfiguration)
        }
        
        if let overlayConfiguration: [String: Any] = arguments["overlayConfiguration"] as? [String: Any] {
            configuration.selectionOverlayConfiguration = ScannerTrackingOverlayConfiguration(overlayConfiguration)
        }
        
        return configuration
    }
    
    struct ScannerTrackingOverlayConfiguration {
         var automaticTrackingEnabled: Bool = false
         var trackingOverlayEnabled: Bool = false

         var trackingPolygonColor: UIColor = UIColor.green
         var trackingHighlightedPolygonColor: UIColor = UIColor.green

         var trackingOverlayTextFormat: SBSDKBarcodeOverlayFormat = .codeAndType

         var trackingTextColor: UIColor = UIColor.black
         var trackingHighlightedTextColor: UIColor = UIColor.white

         var trackingTextContainerColor: UIColor = UIColor.red
         var trackingHighlightedTextContainerColor: UIColor = UIColor.red
         init() { }

         init(_ arguments: [String: Any]) {
             self = ScannerTrackingOverlayConfiguration.parseArguments(arguments: arguments)
         }

         private static func parseArguments(arguments: [String: Any]) -> ScannerTrackingOverlayConfiguration {
             var configuration = ScannerTrackingOverlayConfiguration()

             if let value = arguments["overlayEnabled"] as? Bool {
                 configuration.trackingOverlayEnabled = value
             }
             if let value = arguments["automaticSelectionEnabled"] as? Bool {
                 configuration.automaticTrackingEnabled = value
             }
             if arguments["textFormat"] is String {
                 configuration.trackingOverlayTextFormat = SBSDKBarcodeOverlayFormat.fromArguments(arguments)!
             }
             if let hex = arguments["polygonColor"] as? String {
                 configuration.trackingPolygonColor = UIColor(hexString: hex)
             }
             if let hex = arguments["polygonHighlightedColor"] as? String {
                 configuration.trackingHighlightedPolygonColor = UIColor(hexString: hex)
             }
             if let hex = arguments["textColor"] as? String {
                 configuration.trackingTextColor = UIColor(hexString: hex)
             }
             if let hex = arguments["textHighlightedColor"] as? String {
                 configuration.trackingHighlightedTextColor = UIColor(hexString: hex)
             }
             if let hex = arguments["textContainerColor"] as? String {
                 configuration.trackingTextContainerColor = UIColor(hexString: hex)
             }
             if let hex = arguments["textContainerHighlightedColor"] as? String {
                 configuration.trackingHighlightedTextContainerColor = UIColor(hexString: hex)
             }
             return configuration
         }
     }
    struct ScannerConfiguration {
        
        var acceptedDocumentTypes: [SBSDKBarcodeDocumentType]?
        var acceptedBarcodeTypes: [SBSDKBarcodeType]?
        var engineMode: SBSDKBarcodeEngineMode?
        var additionalDetectionParameters: SBSDKBarcodeAdditionalParameters?
        var gs1Handling: SBSDKGS1Handling?
        var minimumTextLength: UInt?
        var maximumTextLength: UInt?
        var minimum1DBarcodesQuietZone: UInt?
        var msiPlesseyChecksumAlgorithm: SBSDKBarcodeMSIPlesseyChecksumAlgorithm?
        var stripCheckDigits: Bool?
        var barcodeImageGenerationType: SBSDKBarcodeImageGenerationType?
        
        init() { }
        
        init(_ arguments: [String: Any]) {
            self = ScannerConfiguration.parseArguments(arguments: arguments)
        }
        
        private static func parseArguments(arguments: [String: Any]) -> ScannerConfiguration {
            var configuration = ScannerConfiguration()
            
            if arguments["acceptedDocumentFormats"] is [String] {
                configuration.acceptedDocumentTypes = SBSDKBarcodeDocumentType.fromArguments(arguments)
            }

            if arguments["barcodeFormats"] is [String] {
                configuration.acceptedBarcodeTypes = SBSDKBarcodeType.fromArguments(arguments)
            }
            
            if arguments["engineMode"] is String {
                configuration.engineMode = SBSDKBarcodeEngineMode.fromArguments(arguments)!
            }
            
            if let additionalParams = arguments["additionalParameters"] as? [String: Any] {
                configuration.additionalDetectionParameters = SBSDKBarcodeAdditionalParameters(from: additionalParams)
            }
            
            if let value = arguments["minimumTextLength"] as? UInt {
                configuration.additionalDetectionParameters?.minimumTextLength = value
            }
            
            if let value = arguments["maximumTextLength"] as? UInt {
                configuration.additionalDetectionParameters?.maximumTextLength = value
            }
            
            if let value = arguments["minimum1DBarcodesQuietZone"] as? UInt {
                configuration.additionalDetectionParameters?.minimum1DBarcodesQuietZone = value
            }
            
            if let value = arguments["msiPlesseyChecksumAlgorithm"] as? String {
                configuration.additionalDetectionParameters?.msiPlesseyChecksumAlgorithm = SBSDKBarcodeMSIPlesseyChecksumAlgorithm(from: value)
            }
            
            if let value = arguments["stripCheckDigits"] as? Bool {
                configuration.additionalDetectionParameters?.stripCheckDigits = value
            }
            
            if let barcodeImageGenerationType = arguments["barcodeImageGenerationType"] as? String {
                configuration.barcodeImageGenerationType = SBSDKBarcodeImageGenerationType(from: barcodeImageGenerationType)
            }
            return configuration
        }
    }
}
